summaryrefslogtreecommitdiff
path: root/actions/register.php
diff options
context:
space:
mode:
Diffstat (limited to 'actions/register.php')
-rw-r--r--actions/register.php6
1 files changed, 3 insertions, 3 deletions
diff --git a/actions/register.php b/actions/register.php
index 853bd0cf6..aafb54ebb 100644
--- a/actions/register.php
+++ b/actions/register.php
@@ -229,7 +229,7 @@ class RegisterAction extends Action
}
/**
* Check old fashioned PEAR_Error msgs coming from DB_DataObject
*
* In this case nickname and email don't exist in the DB yet,
* so DB_DataObject throws an error. Overrided from Action.
@@ -239,13 +239,13 @@ class RegisterAction extends Action
* @return nothing
*/
- function checkDB_DataObjectError($error) {
+ function handleError($error) {
if ($error->getCode() == DB_DATAOBJECT_ERROR_NODATA) {
// Do nothing.
} else {
- parent::checkDB_DataObjectError($error);
+ parent::handleError($error);
}
}
@@ -229,7 +229,7 @@ class RegisterAction extends Action
}
/**
- * Check old fashioned PEAR_Error msgs coming from DB_DataObject
+ * Handle old fashioned PEAR_Error msgs coming from DB_DataObject
*
* In this case nickname and email don't exist in the DB yet,